package HikSDK

import (
	"testing"
)

func TestNewNvr(t *testing.T) {
	err := Init()
	if err != nil {
		t.Error(err)
		return
	}
	nvr, err := NewNvr("192.168.211.124", 8000, "admin", "guanyaokeji8520")
	if err != nil {
		t.Error(err)
	}
	diff, err := nvr.GetTimeZone()
	if err != nil {
		return
	}
	t.Log(diff)
	month, err := nvr.CheckTimeRegionWithMonth(2025, 5, 1)
	if err != nil {
		return
	}
	t.Log(month)
	timeList, err := nvr.CheckTimeRegionWithDay(2025, 5, 29, 1)
	if err != nil {
		return
	}
	Status := nvr.Status()
	t.Log(Status)
	err = nvr.Logout()
	if err != nil {
		return
	}
	t.Log(timeList)
}
